@@ -27,7 +27,6 @@ def experiment_variable_search(nc_Database,search_path,file_type_list,options,
     #Search the ESGF:
     ctx = conn.new_context(project=nc_Database.drs.project,
                         experiment=experiment)
-    #print ctx.facet_counts
     ctx=ctx.constrain(**{field:var_desc[field_id] for field_id, field in enumerate(nc_Database.drs.var_specs)})
 
     
@@ -146,7 +145,8 @@ def get_url_remote(item,file_type_list,drs):
                 if isinstance(file_info[val],list): file_info[val]=str(file_info[val][0])
             except:
                 file_info[val]=None
-        if (file_info['checksum']!=None and 
-            set(item.urls.keys()).issuperset(drs.required_file_types)):
+        #if (file_info['checksum']!=None and 
+        #    set(item.urls.keys()).issuperset(drs.required_file_types)):
+        if file_info['checksum']!=None:
             url_name.append(file_info)
     return url_name
